<?php

if (! class_exists('EG_Forms_105')) {
	require('lib/eg-forms.inc.php');
}

if (! class_exists('EG_Series_Admin')) {

	/**
	 * Class EG_Series_Admin
	 *
	 * Implement the admin interface of plugin EG-Series
	 *
	 */
	class EG_Series_Admin extends EG_Plugin_109 {

		var $series_data;

		/**
		 * plugins_loaded
		 *
		 * Create the series data object to manage series data
		 *
		 * @param 	none
		 * @return 	none
		 */
		function plugins_loaded() {

			parent::plugins_loaded();

			// Add page for mass posts editing
			$this->add_page('posts', 				/* page type: post, page, option, tool 	*/
							'EG-Series Posts', 		/* Page title 							*/
							'EG-Series Posts', 		/* Menu title 							*/
							'edit_page', 			/* Access level / capability			*/
							'egs_post_edit',		/* file 								*/
							'mass_edit');			/* function								*/

			// Add page for series editing: rename series
			$this->add_page('posts', 				/* page type: post, page, option, tool 	*/
							'EG-Series Edit',		/* Page title 							*/
							'EG-Series Edit',		/* Menu title 							*/
							'edit_page', 			/* Access level / capability			*/
							'egs_series_edit',	 	/* file 								*/
							'edit_series');			/* function								*/

			// Add plugin options page
			$this->add_page('options', 				/* page type: post, page, option, tool 	*/
							'EG-Series options',	/* Page title 							*/
							'EG-Series',			/* Menu title 							*/
							'edit_page', 			/* Access level / capability			*/
							'egs_series_options',	/* file 								*/
							'options_page');		/* function								*/
		} /* End of plugins_loaded */

		/**
		 * init
		 *
		 *
		 *
		 * @param 	none
		 * @return 	none
		 */
		function init() {

			parent::init();

			$this->series_data = & EG_Series_Data::get_instance($this->textdomain);

			if ($this->options['date_format'] == '') {
				$this->options['date_format'] = get_option('date_format');
				update_option($this->options_entry, $this->options);
			}
			// add_action('quick_edit_custom_box', array(&$this, 'quick_edit_custom_box'), 10, 2);

		} /* End of init */

		/**
		 * quick_edit_custom_box
		 *
		 *
		 *
		 * @param 	string	$column_name	Name of the column
		 * @param	string	$type			???
		 * @return 	none
		 */
		function quick_edit_custom_box($column_name, $type) {

			if ($column_name == 'serie') {

				// Get the default value
				// $meta_key = $this->options['custom_field_name'];
				// if (isset($post->ID)) $current_category = get_post_meta($post->ID, $meta_key, TRUE);

				$values = $this->series_data->get_series( $this->options['custom_field_name'],  /* $meta_key */
										'select',			/* list_type 	 */
										0, 					/* width 		 */
										0, 					/* height		 */
										'',					/* title		 */
										'',					/* html title tag*/
										'eg-series-select',	/* select name   */
										'',					/* Default value */
										0, 					/* auto_submit	 */
										0,					/* more_series	 */
										1);					/* add no_serie  */


				/* Ajout d'une ligne? (tr td colspan=9?)

				bulk: selection de la serie + nouvelle serie
				quick: selection de la serie + nouvelle serie + order number
				*/
				echo '<fieldset class="inline-edit-col-right">'.
						'<div class="inline-edit-col">'.
							'<div class="inline-edit-group">'.
								'<label>'.
								'<span class="title">'.__( 'Serie', $this->textdomain ).'</span>'.
								$values.
								'</label>'.
							'</div>'.
						'</div>'.
					'</fieldset>';
			}
		} // End of quick_edit_custom_box

		/**
		 * admin_menu
		 *
		 * Add metabox and save post action
		 *
		 * @param	none
		 * @return 	none
		 */
		function admin_menu() {
			parent::admin_menu();

			if ($this->options['use_metabox'] && function_exists( 'add_meta_box' )) {
				add_meta_box( 'eg-series-metabox', __( 'EG-Series', $this->textdomain ),
							array(&$this, 'display_metabox'), 'post', 'normal', 'high' );

				add_meta_box( 'eg-series-metabox', __( 'EG-Series', $this->textdomain ),
							array(&$this, 'display_metabox'), 'page', 'normal', 'high' );

				add_action( 'save_post', array(&$this, 'save_metabox'), 10, 2);
			}
		} // End of admin_menu

		/**
		 * display_metabox
		 *
		 * Display series meta box
		 *
		 * @param	object	$post		post or page currently edited
		 * @param	array	$args		other arguments
		 * @return 	none
		 */
		function display_metabox($post, $args) {

			// Get the default value
			$meta_key = $this->options['custom_field_name'];
			if (isset($post->ID)) $current_category = get_post_meta($post->ID, $meta_key, TRUE);

			$select_series = $this->series_data->get_series(
											$this->options['custom_field_name'],
											'select',
											0, 						/* width 		 */
											0, 						/* height		 */
											'',						/* title		 */
											'',						/* html title tag*/
											'eg-series-select', 	/* select name   */
											$current_category,		/* default value */
											0, 						/* auto_submit	 */
											0,						/* more_series	 */
											1);						/* add no_serie  */

			$string = '<table>';
			if ($select_series != '') {
				$string .= '<tr>'.
						'<td valign="top">'.
							'<label for="eg-series-select">'.__('Existing serie: ', $this->textdomain).'</label>'.
						'</td>'.
						'<td>'.
							$select_series.
							__('select an existing serie', $this->textdomain).
						'</td>'.
					'</tr>';
			}
			$string .= '<tr>'.
						'<td valign="top">'.
							'<label for="eg-series-new">'.__('New serie: ', $this->textdomain).'</label>'.
						'</td>'.
						'<td>'.
							'<input type="text" name="eg-series-new" value="" />'.
							'<br />'.__('or give a name to create a new one', $this->textdomain).
						'</td>'.
					'</tr>'.
					'</table>';
			echo $string;
		} // End of display_metabox

		/**
		 * save_metabox
		 *
		 * Save selected serie
		 *
		 * @param 	int		$post_id		id of the currently edited post
		 * @param	object	$post			post or page currently edited
		 * @return 	none
		 */
		function save_metabox($post_id, $post) {

			// Don't work for revision
			if ($post->post_type == 'post' || $post->post_type == 'page') {

				$meta_key       = $this->options['custom_field_name'];
				$previous_value = get_post_meta($post->ID, $meta_key, TRUE);

				$eg_series_new    = $_POST['eg-series-new'];
				$eg_series_select = $_POST['eg-series-select'];

				if ($eg_series_new != '') {
					if ($previous_value == '') add_post_meta($post_id, $meta_key, $eg_series_new, true);
					else update_post_meta($post_id, $meta_key, $eg_series_new);
				}
				else {
					if ($eg_series_select == 'no_serie')
						delete_post_meta($post_id, $meta_key, $previous_value);
					elseif ($eg_series_select != $previous_value)
						update_post_meta($post_id, $meta_key, $eg_series_select);
				} // End of eg_series_new != ""
			} // End of post_type = post or page
		} // End of save_metabox

		/**
		 * admin_init
		 *
		 * Initialize function: add metabox to the plugin
		 *
		 * @param 	none
		 * @return 	none
		 */
		function admin_init() {
			// global $wp_version;

			// Call the parent init function
			parent::admin_init();

			// Add columns to the post list (menu Manage)
			if ($this->options['display_columns']) {
				add_filter('manage_posts_columns', array(&$this, 'manage_col_def') );
				add_action('manage_posts_custom_column', array(&$this, 'manage_col'), 10, 2 );
			}
		} /* End of admin_init */

		/**
		 * manage_col_def
		 *
		 * Add columns to the admin page: manage post
		 *
		 * @package EG-Series
		 * @param array	$cols		list of columns header
		 * @return array	$cols
		 */
		function manage_col_def($cols) {
			$cols['serie'] = __('Serie', $this->textdomain);
			return $cols;
		} /* End of manage_col_def */

		/**
		 * manage_col
		 *
		 * Complete the column 'serie'
		 *
		 * @package EG-Series
		 * @param string	$column_name	name of the column
		 * @param int		$id				post id
		 * @return none
		 */
		function manage_col($column_name, $id) {
			if ($column_name == 'serie') echo htmlspecialchars(get_post_meta($id, $this->options['custom_field_name'], true));
			else echo '&nbsp;';
		} /* End of manage_col */

		/**
		 * add_form
		 *
		 * create form
		 *
		 * @package EG-Series
		 *
		 * @param none
		 * @return none
		 */
		function add_form() {
			$this->options_form = new EG_Forms_105('EG-Series Options', '', '', $this->textdomain, '', 'icon-options-general', 'egs_options', 'mailto:'.EG_SERIES_AUTHOR_EMAIL);
			$form = & $this->options_form;

			$id_section = $form->add_section('Interface');
			$id_group   = $form->add_group($id_section, 'Post management list');
			$form->add_field($id_section, $id_group, 'checkbox', 'Add column \'Series\' to the post management page', 'display_columns');
			$id_group   = $form->add_group($id_section, 'Post editor page');
			$form->add_field($id_section, $id_group, 'checkbox', 'Use metabox to enter the series, rather than enter custom fields manually.', 'use_metabox', '', '', 'Plugin can display a metabox in the post editor page, to make easy the serie choice or creation. But you can hide this metabox, and enter manually series name if the custom field');

			$id_section = $form->add_section('Shortcodes options', 'You can choose keywords you want use for shortcodes.<br />Change them just after the plugin installation. In other case, all EG-Series shortcodes already used in posts, won\'t work properly after the change.');
			$id_group   = $form->add_group($id_section, 'Shortcode to list series');
			$form->add_field($id_section, $id_group, 'text', 'Shortcode to list series', 'shortcode_list_series', '', '', 'Use to list series in a post');
			$id_group   = $form->add_group($id_section, 'Shortcode to list posts');
			$form->add_field($id_section, $id_group, 'text', 'Shortcode to list posts', 'shortcode_list_posts', '', '', 'Use to list all posts of the same serie than the current post');
			$id_group   = $form->add_group($id_section, 'Date Format');
			$form->add_field($id_section, $id_group, 'text', 'Date format: ', 'date_format', '', '('.date_i18n($this->options['date_format']).')',
											'Use PHP date() parameters to configure the date:<br />d&nbsp;&nbsp;&nbsp;&nbsp;Day of the month, 2 digits with leading zeros<br />D&nbsp;&nbsp;&nbsp;&nbsp;A textual representation of a day, three letters<br />j&nbsp;&nbsp;&nbsp;&nbsp;Day of the month without leading zeros<br />S&nbsp;&nbsp;&nbsp;&nbsp;English ordinal suffix for the day of the month, 2 characters<br />F&nbsp;&nbsp;&nbsp;&nbsp;A full textual representation of a month, such as January or March<br />m&nbsp;&nbsp;&nbsp;&nbsp;Numeric representation of a month, with leading zeros<br />M&nbsp;&nbsp;&nbsp;&nbsp;A short textual representation of a month, three letters<br />n&nbsp;&nbsp;&nbsp;&nbsp;Numeric representation of a month, without leading zeros<br />Y&nbsp;&nbsp;&nbsp;&nbsp;A full numeric representation of a year, 4 digits<br />y&nbsp;&nbsp;&nbsp;&nbsp;A two digit representation of a year');

			$id_group   = $form->add_group($id_section, 'Auto shortcode');
			$form->add_field($id_section, $id_group, 'select', 'Automatically add the list of posts that are in the same serie than the current displayed post: ', 'shortcode_auto', '', '', '', '', 'regular', array( 0 => 'Not activated', 2 => 'At the end')); // 1 => 'At the beginning'
			$form->add_field($id_section, $id_group, 'checkbox', 'Activate automatic shortcode on the following cases', 'shortcode_auto_where', '', '', '', '', 'regular', array( 'home' => 'Homepage,', 'post' => 'Post,', 'page' => 'Page,', 'index' => 'Lists of posts.'));

			$form->add_field($id_section, $id_group, 'text', 'Title of the list: ', 'shortcode_auto_title');
			$form->add_field($id_section, $id_group, 'text', 'HTML Tag for title: ', 'shortcode_auto_title_tag');
			$form->add_field($id_section, $id_group, 'select', 'List type: ', 'shortcode_auto_listtype', '', '', '', '', 'regular', array( 'select' => 'Select', 'ul' => 'Simple list', 'ol' => 'Ordered list') );
			$form->add_field($id_section, $id_group, 'select', 'Order by: ', 'shortcode_auto_orderby', '', '', '', '', 'regular', array( 'date' => 'Date', 'title' => 'Title') );
			$form->add_field($id_section, $id_group, 'select', 'Order: ', 'shortcode_auto_order', '', '', '', '', 'regular', array( 'ASC' => 'Ascending', 'DESC' => 'Descending') );
			$form->add_field($id_section, $id_group, 'checkbox', 'Display dates if checked', 'shortcode_auto_show_date', 'Display dates? ', '', '', '', 'regular' );
			$form->add_field($id_section, $id_group, 'checkbox', 'Do you want that auto shortcode options become the default options for the TinyMCE EG-Series Editor?', 'shortcode_auto_default_opts', 'Default options? ', '', '', '', 'regular' );

			$id_section = $form->add_section('Custom fields options', 'You can choose the custom field you want to use to implement series. You can change this value at any time: the field will be change automatically in the WordPress database.');
			$id_group   = $form->add_group($id_section, 'Choose the custom field to use');
			$form->add_field($id_section, $id_group, 'text', 'Custom field to use', 'custom_field_name', '', '', 'If you already have a field used for series.');

			$id_section = $form->add_section('Uninstallation', '', 'Be careful: the deletion can\'t be cancelled');
			$id_group   = $form->add_group($id_section, 'Options');
			$form->add_field($id_section, $id_group, 'checkbox', 'Check if you want to delete options while plugin uninstallation', 'uninstall_del_option', '', '', '', '', 'regular' );
			$id_group   = $form->add_group($id_section, 'Custom fields');
			$form->add_field($id_section, $id_group, 'checkbox', 'Check if you want to delete custom fields', 'uninstall_del_custom_field', '', '', '', '', 'regular' );

			$form->add_button('submit', 'eg_series_options_submit', 'Save changes');
			$form->add_button('reset', 'eg_series_options_reset', 'Cancel changes');
			$form->add_button('submit', 'eg_series_options_reset', 'Reset to defaults', 'reset_to_defaults');

		} /* End of add_form */


		/**
		 * options_page
		 *
		 * Display the options page
		 *
		 * @param 	none
		 * @return 	none
		 */
		function options_page() {
			global $EG_SERIES_DEFAULT_OPTIONS;

			$this->add_form();

			$results = $this->options_form->get_form_values($this->options, $EG_SERIES_DEFAULT_OPTIONS, $this->options_entry);
			if ($results)
				$this->options = $results;

			$this->options_form->display_form($this->options);

		} /* options_page */

		/**
		 * update_mass_serie
		 *
		 *  Get results from the form, and update the database.
		 *
		 * @param 	none
		 * @return 	none
		 */
		function update_mass_series() {

			// Detect if user click on the submit button
			$updated = 0;
			if (isset($_POST['eg_series_update_mass'])) {

				// check security
				check_admin_referer( 'eg_series_mass_edit' );

				/* Get the list of the serie per post */
				$current_series = $_POST['series'];
				$new_series     = $_POST['new_series'];
				$previous       = $_POST['previous_series'];
				$meta_key       = $this->options['custom_field_name'];

				foreach ($previous as $post_id => $previous_value) {

					$new_value = '';
					if ($new_series[$post_id] != '') {
						$new_value = $new_series[$post_id];
					}
					else {
						$current_serie = $current_series[$post_id];
						if ($current_serie != 'no_serie' && $current_serie != '') {
							$new_value = $current_serie;
						}
					}
					if ($new_value != $previous_value) {
						$updated ++;
						if ($new_value == '') {
							delete_post_meta($post_id, $meta_key);
						}
						else {
							if ($previous_value == '') {
								add_post_meta($post_id, $meta_key, $new_value, TRUE);
							}
							else {
								update_post_meta ($post_id, $meta_key, $new_value);
							}
						}
						clean_post_cache($post_id);
					}
				} /* End for loop */

				if ($updated > 0) {
					$this->display_message(sprintf(__('%s posts were updated successfully !', $this->textdomain), $updated));
					$this->series_data->get_series_details($meta_key, TRUE);
				}
			} /* End of if $_POST */
			return ($update != 0);
		} /* End of update_mass_series */

		/**
		 * mass_edit_post_filter
		 *
		 * Display form allowing to filter the list of posts, by post_status, date, category
		 *
		 * Thanks to Armaury Balmer and its simple tags plugin that was a good source of tips for these 'mass edit' function.
		 *
		 * @param 	none
		 * @return 	none
		 */
		function mass_edit_post_filter() {
			global $wpdb, $wp_query, $wp_locale;

			$status_title = array(
				'all'     => __('All posts', $this->textdomain),
				'future'  => __('Future',    $this->textdomain),
				'publish' => __('Published', $this->textdomain),
				'draft'   => __('Draft',     $this->textdomain),
				'pending' => __('Pending',   $this->textdomain)
			);

			$post_per_page = 20;

			/* Manage the number of the page requested */
			if ( !isset( $_GET['paged'] ) ) {
				$_GET['paged'] = 1;
			}

			// Build posts query parameters
			$order   = 'DESC';
			$orderby = 'date';
			if (! isset($_GET['post_status'])) $requested_status = '';
			else {
				$requested_status = $_GET['post_status'];
				if ($requested_status == 'draft' || $requested_status == 'pending') {
					$order   = 'ASC';
					$orderby = 'modified';
				}
				echo '<input type="hidden" name="post_status" value="'.attribute_escape($requested_status).'" />';
			}

			// Get date parameter
			$requested_date  = 0;
			if (isset($_GET['m'])) {
				$requested_date = $_GET['m'];
				$_GET['m'] = (int) $_GET['m'];
			}

			// Get category parameter
			$requested_category = '';
			if (isset($_GET['cat'])) {
				$requested_category = $_GET['cat'];
				$_GET['cat'] = (int) $_GET['cat'];
			}

			/* Query the list of the posts to display */
			// post_type=post&what_to_show=posts&
			wp('post_type=any&post_status='.$requested_status.'&posts_per_page='.$post_per_page.'&order='.$order.'&orderby='.$orderby);

			// Display post status filter
			$url_params = ($requested_date==0 ? '' : '&amp;m='.$requested_date).
			              ($requested_category=='' ? '' : '&amp;cat='.$requested_category );
			$num_posts = wp_count_posts('post', 'readable');
			echo '<ul class="subsubsub">';
			$class = ($requested_status == '' ? ' class="current"' : '');
			echo '<li> <a href="edit.php?page=egs_post_edit'.$url_params.'" '.$class.'>'.$status_title['all'].'</a></li>';
			foreach ($num_posts as $status => $number) {
				$class = ($requested_status == $status ? ' class="current"' : '');
				echo '<li> | <a href="edit.php?page=egs_post_edit'.$url_params.'&amp;post_status='.$status.'" '.$class.'>'.$status_title[$status].' '.($number<0?'':'('.$number.')').'</a></li>';
			}
			echo '</ul>'.
			     '<div class="tablenav">'.
				 '<form id="posts-filter" action="" method="get">'.
				 '<input type="hidden" name="page" value="egs_post_edit" />';

			if ( !is_singular() ) {
				$arc_result = wp_cache_get( 'arc_result', 'eg-series' );
				if (! $arc_result) {
					$arc_result = $wpdb->get_results( 'SELECT DISTINCT YEAR(post_date) AS yyear, MONTH(post_date) AS mmonth FROM '.$wpdb->posts.' WHERE post_type = "post" ORDER BY post_date DESC' );
					wp_cache_set('arc_result', $arc_result, 'eg-series', $this->cacheexpiration);
				}

				$month_count = count($arc_result);
				if ( $month_count && !( 1 == $month_count && 0 == $arc_result[0]->mmonth ) ) {
					echo '<select name="m">'.
					     '<option>'.__('Show all dates').'</option>';
					foreach ($arc_result as $arc_row) {
						if ( $arc_row->yyear != 0 ) {
							$arc_row->mmonth = zeroise( $arc_row->mmonth, 2 );

							if ( $arc_row->yyear.$arc_row->mmonth == $requested_date ) $default = ' selected="selected"';
							else $default = '';

							echo '<option'.$default.' value="'.$arc_row->yyear.$arc_row->mmonth.'">'.
							     $wp_locale->get_month($arc_row->mmonth) . ' '.$arc_row->yyear.
							     '</option>';
						}
					}
					echo '</select> ';
				}

				wp_dropdown_categories(array('show_option_all' => __('View all categories'),
				                          'hide_empty'      => 1,
										  'hierarchical'    => 1,
										  'show_count'      => 1,
										  'orderby'         => 'name',
										  'selected'        => $requested_category));
				echo ' <input type="submit" id="post-query-submit" value="'.__('Filter').'" class="button-secondary" />';

			}

			/* Display the page link management block */
			$page_links = paginate_links( array(
						'base' => add_query_arg( 'paged', '%#%' ),
						'format' => '',
						'total' => ceil($wp_query->found_posts / $post_per_page ),
						'current' => ((int) $_GET['paged'])
					));

			if ( $page_links )	echo '<div class="tablenav-pages">'.$page_links.'<br/>&nbsp;</div>';
			echo '</form></div>';
		} /* End of mass_edit_post_filter */

		/**
		 * mass_edit
		 *
		 * Allow to edit series field for all posts
		 *
		 * Thanks to Armaury Balmer and its simple tags plugin that was a good source of tips for these 'mass edit' function.
		 *
		 * @param 	none
		 * @return 	none
		 */
		function mass_edit() {

			/* Display the page title */
			echo '<div id="icon-tools" class="icon32"><br /></div>'.
				 '<div class="wrap">'.
				 '<h2>'.__('EG-Series Mass Edit', $this->textdomain).'</h2>';

			// Update posts according fields of form
			$this->update_mass_series();

			// --- Display the form allowing to filter posts ---
			$this->mass_edit_post_filter();

			if ( have_posts() ) {

				// if ($series_list === FALSE) $series_list = __('No serie available', $this->textdomain);

				/* Display the list of the posts */
				echo '<form name="post" id="post" method="post">'.
					wp_nonce_field('eg_series_mass_edit').
				     '<table class="widefat" cellspacing="0">'.
					 '<thead>'.
					 '<tr>'.
					 '<th class="manage-column">'.__('Title', $this->textdomain).'</th>'.
					 '<th class="manage-column">'.__('Type', $this->textdomain).'</th>'.
					 '<th class="manage-column">'.__('Date', $this->textdomain).'</th>'.
					 '<th class="manage-column">'.__('Status', $this->textdomain).'</th>'.
					 '<th class="manage-column">'.__('Serie', $this->textdomain).'</th>'.
					 '<th class="manage-column">'.__('New serie', $this->textdomain).'</th>'.
					 '</tr>'.
					 '</thead>'.
					 '<tbody>';
				$class = 'alternate';

				$meta_key = $this->options['custom_field_name'];
				while (have_posts()) {
					the_post();
					$index = get_the_ID();
					// Get the serie of the current posts ( = '' if no serie)
					$post_serie = get_post_meta($index, $meta_key, TRUE);

					// Get the list of series and store it in an array
					$select_series = $this->series_data->get_series($this->options['custom_field_name'],
															'select',				/* list_tag 			*/
															0, 						/* width 				*/
															0, 						/* height				*/
															'',						/* title				*/
															'',						/* html tag for title 	*/
															'series['.$index.']',	/* Select/option name   */
															$post_serie,			/* Default value 		*/
															FALSE, 					/* auto_submit			*/
															0,						/* more_series			*/
															TRUE);					/* add no_serie 		*/

					// Keep the current value and display the form
					echo '<tr '.($class==''?'':'class="'.$class.'"').' >'.
						 '<input type="hidden" name="previous_series['.$index.']" value="'.$post_serie.'" />'.
						 '<td><a href="post.php?action=edit&post='.$index.'" title="'.__('Edit', $this->textdomain).'">'.
						 get_the_title().
					     '</a></td>'.
						 '<td>'.__(get_post_type(), $this->textdomain).'</td>'.
						 '<td>'.get_the_time('d F Y').'</td>'.
						 '<td>'.__(get_post_status($index), $this->textdomain).'</td>'.
						 '<td>'.$select_series.'</td>'.
						 '<td><input type="text" name="new_series['.$index.']" size="10" /></td>'.
						 '</tr>';
					$class = ( $class == 'alternate' ) ? '' : 'alternate';
				}
				echo '</tbody></table>'.
					 '<p class="submit">'.
					 '<input class="button" type="submit" name="eg_series_update_mass" value="'.__('Update all &raquo;', $this->textdomain).'" /></p></form></div>';
			}
		} /* End of mass_edit */

		/**
		 * edit_series
		 *
		 * Edit series (allow to rename them)
		 *
		 * @param 	none
		 * @return 	none
		 */
		function edit_series() {
			global $wpdb;

			$meta_key = $this->options['custom_field_name'];

			// if user click on the submit button
			if (isset($_POST['eg_series_rename'])) {

				// check security
				check_admin_referer('eg_series_edit');

				// Get list of series
				$series = $_POST['series'];
				$updated = 0;
				if (isset($series) && sizeof($series)>0) {

					// For each serie, test if the name exist, and if the new name is different than the previous
					foreach ($series as $old_name => $new_name) {
						if ($new_name != '' && $new_name != $old_name) {
							// Count number of updates
							$updated++;
							// Update database
							$sql = $wpdb->prepare( 'UPDATE '.$wpdb->postmeta.' SET meta_value="%s" WHERE meta_key = "%s" AND meta_value = "%S"', $new_name, $meta_key, $old_name);
							$wpdb->get_query( $sql );
						}
					}
				}
				// if number of updates > 0, clear cache and then display an update message.
				if ($updated)
					$this->display_message(sprintf(__('%s series were updated successfully !', $this->textdomain),$updated), 'updated');
			}

			if (isset($_POST['eg_series_delete'])) {
				// check security
				check_admin_referer('eg_series_edit');

				$series = $_POST['series_to_delete'];

				$deleted = 0;
				if (isset($series) && sizeof($series)>0) {
					foreach ($series as $serie) {
						$deleted++;
						$sql = $wpdb->prepare('DELETE FROM '.$wpdb->postmeta.' WHERE meta_key="%s" AND meta_value="%s"', $meta_key, $serie);
						$wpdb->query($sql);
					}
					// if number of updates > 0, clear cache and then display an update message.
					if ($deleted)
						$this->display_message(sprintf(__('%s series were deleted successfully !', $this->textdomain),$deleted));
				}
			}
			// Refresh the list of series
			$values = $this->series_data->get_series_details($this->options['custom_field_name'],($updated>0||$delete>0));

			echo '<div id="icon-tools" class="icon32"><br /></div>'.
					'<div class="wrap">'.
					'<h2>'.__('EG-Series Series Editor', $this->textdomain).'</h2>';
			if ( $values === FALSE || sizeof($values)==0 ) {
				_e('No serie available yet', $this->textdomain);
			}
			else {
				/* Display the page title */
				echo '<form name="post" id="post" method="post">'.
					wp_nonce_field('eg_series_edit').
					'<table class="widefat" cellspacing="0">'.
					'<thead>'.
					'<tr>'.
					'<th>&nbsp;</th>'.
					'<th class="manage-column">'.__('Series', $this->textdomain).'</th>'.
					'<th class="manage-column">'.__('New name', $this->textdomain).'</th>'.
					'</tr>'.
					'</thead>'.
					'<tbody>';

				// Display series list
				$class = 'alternate';
				foreach ($values as $serie_name => $serie_values) {
					echo '<tr>'.
						'<td><input type="checkbox" name="series_to_delete[]" value="'.$serie_name.'" /></td>'.
						'<td>'.$serie_name.' ('.sizeof($serie_values).__(' posts', $this->textdomain).')</td>'.
						'<td><input type="text" name="series['.$serie_name.']" /></td>'.
						'</tr>';
				}
				echo '</tbody></table>'.
					'<p class="submit">'.
					'<input class="button" type="submit" name="eg_series_rename" value="'.__('Update all &raquo;', $this->textdomain).'" /> '.
					'<input class="button" type="submit" name="eg_series_delete" value="'.__('Delete checked series', $this->textdomain).'" /></p>'.
					'</form>';
			}
			echo '</div>';
		} /* End of Edit_series */

	} /* End of class */
} /* End of class_exists */

$eg_series_admin = new EG_Series_Admin(EG_SERIES_PLUGIN_NAME,
										EG_SERIES_VERSION,
										EG_SERIES_CORE_FILE,
										EG_SERIES_OPTIONS_ENTRY,
										$EG_SERIES_DEFAULT_OPTIONS);

$eg_series_admin->set_textdomain(EG_SERIES_TEXTDOMAIN);
$eg_series_admin->add_tinymce_button( 'EGSeries', 'tinymce');
$eg_series_admin->set_wp_versions('2.5', FALSE, FALSE, FALSE);
$eg_series_admin->load();

?>
