<?php

if (! class_exists('EG_Series_data')) {

	/**
	 * Class EG_Series_data
	 *
	 * Implement a shortcode to display the posts series
	 *
	 */
	class EG_Series_Data {

		var $textdomain;

		/**
		 * EG_Series_data
		 *
		 * Constructor for PHP 4
		 *
		 * @package EG-Series
		 * @param string	$textdomain	text domain of the plugin
		 * @return none
		 */
		function EG_Series_data($textdomain, $is_singleton=FALSE) {
			$is_singleton || die('Cannot instantiate '.get_class($this).' class directly!\n');

			$this->textdomain = $textdomain;
		} /* End of EG_Series_data */

		/**
		 * __construct
		 *
		 * Constructor for PHP 5
		 *
		 * @package EG-Series
		 * @param string	$textdomain	text domain of the plugin
		 * @return none
		 */
		function __construct($textdomain, $is_singleton=FALSE) {
			$is_singleton || die('Cannot instantiate '.get_class($this).' class directly!\n');

			$this->textdomain = $textdomain;
		} /* End of __construct */

		function &get_instance($textdomain) {
			static $eg_series_instance;

			if (!is_object($eg_series_instance))
				$eg_series_instance = new EG_Series_Data($textdomain, TRUE);

			return $eg_series_instance;
		} /* End of get_instance */

		/**
		 * build_lists
		 *
		 * Build $posts_list and $series_list
		 *
		 * @package EG-Series
		 * @param string		$meta_key		meta key used to store serie
		 * @param boolean	$force_refresh	if TRUE, build lists even if they exist
		 * @return none
		 */
		function build_lists($meta_key, $force_refresh=FALSE) {
			global $wpdb;
			
			$series_list = FALSE;
			if ($force_refresh) wp_cache_delete('series_list', EG_SERIES_CACHE_GROUP);
			
			if (trim($meta_key) != '') {
				$series_list = wp_cache_get('series_list', EG_SERIES_CACHE_GROUP);
				if (! $series_list) {
					$sql = $wpdb->prepare('SELECT DISTINCT ID, meta_value, post_title, post_date, post_status, menu_order FROM '.$wpdb->posts.' , '.$wpdb->postmeta.' WHERE meta_key="%s" AND ID=post_id ORDER BY meta_value ASC, post_date ASC', $meta_key);

					$results = $wpdb->get_results($sql);
					if ($results) {
						// List the results and build the series_list and the post_list
						foreach ($results as $result) {
							$series_list[$result->meta_value][] = $result;
						}
						wp_cache_set('series_list', $series_list, EG_SERIES_CACHE_GROUP, EG_SERIES_CACHE_EXPIRATION);
						unset($results);
					} // End of "results not empty"	
				} // End of "No data in cache"
			} // Meta_key defined
			
			return ($series_list);
		} /* End of build_lists */

		/**
		 * get_series_details
		 *
		 * Get the entire $series_list
		 *
		 * @package EG-Series
		 * @param string	$meta_key		meta key used to store serie
		 * @return array				series list
		 */
		function get_series_details($meta_key, $force_refresh=FALSE) {
			// Build the list if required
			return ($this->build_lists($meta_key, $force_refresh));
		} /* End of get_series_details */

		/**
		 * get_post_serie
		 *
		 * Get the serie of the specified post
		 *
		 * @package EG-Series
		 * @param string	$meta_key		meta key used to store serie
		 * @param int	$post_id		ID of the post
		 * @return string				serie of the post (or '')
		 */
		function get_post_serie($meta_key, $post_id) {
			return get_post_meta($post_id, $meta_key, TRUE);
		} /* get_post_serie */

		/**
		 * get_series
		 *
		 * Get series with different formats
		 *
		 * @package EG-Series
		 * @param string	$meta_key		meta key used to store serie
		 * @param string	$list_type		type of list (select, ol, ul, dl, array)
		 * @param int		$width			width of the list
		 * @param int		$height			if select => height of the select field, if ol or ul => number of series to display
		 * @param boolean	$auto_submit	if select => submit field without click on button
		 * @param int		$more_series	id of a post or a page where the entire list of series can be displayed
		 * @param boolean	$add_no_serie	add additional empty option
		 * @param int		$post_id		ID of the post
		 * @return string					serie of the post (or '')
		 */
		function get_series($meta_key,
						$list_type    = 'ol',
						$width        = 0,
						$height       = 0,
						$title        = '',
						$titletag     = '',
						$select_name  = 'series_list',
						$default_value = '',
						$auto_submit  = 0,
						$more_series  = 0,
						$add_no_serie = 0,
						$list_posts   = 0,
						$show_date    = 1,
						$post_orderby = 'date',
						$post_order   = 'ASC') {

			// Build the lists if they are empty
			$series_list = $this->build_lists($meta_key);

			$value = FALSE;
			// If list not empty
			if (! isset($series_list) || sizeof($series_list) == 0)
				return '';

			if ($title != '' && $titletag != '')
				$title_string = '<'.$titletag.'>'.htmlspecialchars(__($title, $this->textdomain)).'</'.$titletag.'>';
				
			switch ($list_type) {
				case 'select':
					// Manage Auto-Submit
					if ($auto_submit) $onchange_string =  'onChange="window.location=this.value"';
					else $onchange_string = '';
					
					// Manage add_no_serie
					if ($add_no_serie) $string = '<option class="eg-series-series-item" value="no_serie"> </option>';

					// Build the list
					foreach ($series_list as $serie_name => $posts_list) {

						if ($width>0 && strlen($serie_name)>$width) 
							$label = wp_html_excerpt( $serie_name, $width-3 ).'...';
						else
							$label = $serie_name;

						$first_post = current($posts_list);

						$selected = '';
						if ($auto_submit) 
							$link = get_permalink($first_post_id);
						else {
							$link = $serie_name;
							if ($link == $default_value) $selected = 'selected';
						}

						$string .= '<option class="eg-series-series-item" value="'.$link.'" '.$selected.'>'.
								htmlspecialchars($label).
								'</option>';
					}
					// If list is not empty, finalize it
					if ($string != '')
						$string = $title_string.'<select class="eg-series-series" id="'.$select_name.'" name="'.$select_name.'" '.($height==0?'':'size="'.$height.'"').' '.$onchange_string.'>'.$string.'</select><br />';

				break;

				// HTML ul or ol list
				case 'ul':
				case 'ol':
					$number = 1;
					foreach ($series_list as $serie_name => $posts_list) {

						if ($width>0 && strlen($serie_name)>$width) 
							$label = wp_html_excerpt( $serie_name, $width-3 ).'...';
						else
							$label = $serie_name;

						if ($list_posts) {
							$string .= '<li class="eg-series-series-item">'.htmlspecialchars($serie_name).
									$this->get_posts($meta_key,	/* meta key        */
											$serie_name,		/* name            */
											0,             		/* current post id */
											$list_type,			/* List type       */
											$width,				/* width           */
											0,					/* height		   */
											'',					/* title           */
											'',					/* title tag       */
											0,					/* auto submit     */
											$post_orderby,		/* order_by	       */
											$post_order,   	    /* order           */
											$show_date).     	/* show_date       */
									'</li>';
						}
						else {
							$first_post = current($posts_list);
							$string .= '<li class="eg-series-series-item">'.
								'<a href="'.get_permalink($first_post->ID).'" title="'.htmlspecialchars($first_post->post_title).'">'.$label.'</a>'.
								'</li>';
						}
						$number++;
						// Stop the list if we reach the number of series required
						if ($height!=0 && $number>$height) break;

					} // End of foreach series
					if ($string != '') {
						// Add the "more series" link
						if ($more_series && $height!=0 && sizeof($series_list)>$height) {
							$string .= '<li class="eg-series-series-item">'.
								'<a href="'.get_permalink($more_series).'" title="'.__('See more series', $this->textdomain).'">'.__('More series', $this->textdomain).'</a>'.
								'</li>';
						}
						// Finalize the list
						if ($string != '')
							$string = $title_string.
								'<'.$list_type.' class="eg-series-series">'.$string.'</'.$list_type.'>';
					}
				break;

				case 'array':
					// Special type: not HTML code, just build an array
					if ($add_no_serie) $string = array( 'no_serie' => ' ');
					foreach ($series_list as $serie_name => $serie_values) {
						$string[$serie_name] = $serie_name;
					}
				break;
			} /* end of switch */

			return ($string);
		} /* End of get_series */

		/**
		 * sort_posts
		 *
		 * Sort list of posts,
		 *
		 * @package EG-Series
		 *
		 * @param array		$posts_list			List of posts to sort,
		 * @param string	$orderby			sort key,
		 * @param string	$order				sort order
		 * @return array	 					sorted list of posts,
		 */
		function sort_posts($posts_list, $orderby, $order) {

			if ( strcasecmp($orderby,'date')==0 && strcasecmp($order,'asc')==0 ) {
				return ($posts_list);
			}
			else {
				$order = ( strcasecmp($order,'ASC')==0 ? -1 : 1 );
				if ( stripos($orderby, 'post_') === FALSE ) $orderby = 'post_'.$orderby;
				$result_code = uasort($posts_list, create_function('$a,$b', '$a1=$a->'.$orderby.'; $b1=$b->'.$orderby.'; if ($a1==$b1) return 0; else return ($a1<$b1) ? '.$order.' : '.-$order.';'));
				return ($posts_list);
			}
		}

		/**
		 * Get_posts
		 *
		 * Get series with different formats
		 *
		 * @package EG-Series
		 * @param string	$meta_key			meta key used to store serie,
		 * @param string	$name				name of the serie,
		 * @param int		$current_post_id	ID of the post where to get serie,
		 * @param string	$list_type			list type (select, ol, ul, dl),
		 * @param int		$width				width of the list,
		 * @param int		$height				number of post (depredicated, no more used)
		 * @param string	$title				title of the list,
		 * @param string	$titletag			html tag to use to display title,
		 * @param int       $auto_submit        autosubmit the choice (list_type=select only),
		 * @param string    $orderby            field to use to sort the list,
		 * @param string	$order				post order (ASC or DESC)
		 * @param int	    $show_date			1 or 0, show date or note
		 * @param string    $date_format		format for the date. Default: '' => use WP option
		 * @param int       $expand             0: list only post title, 1: display excerpt
		 * @return string						list of posts of the specified serie
		 */
		function get_posts($meta_key,
							$name		  = '',
							$current_post_id = 0,
							$list_type	  = 'ol',
							$width		  = 0,
							$height		  = -1,			/* depredicated */
							$title		  = '',
							$titletag	  = 'h2',
							$auto_submit  = 1,
							$orderby      = 'date',
							$order		  = 'DESC',
							$show_date    = 1,
							$date_format  = '',
							$expand       = 0) {

			// Build the list if required
			$series_list = $this->build_lists($meta_key);

			$string = '';
			if (!isset($series_list) || sizeof($series_list) == 0)
				return '';

			if ($date_format == '') $date_format = get_option('date_format');

			$serie = '';
			if (! $current_post_id) {
				global $post;
				$current_post_id = $post->ID;
			}
			$serie = $this->get_post_serie($meta_key, $current_post_id);

			// Name specified
			if ($name != '' && isset($series_list[$name]))
				$serie = $name;

			if ($serie == '')
				return ('');

			switch ($list_type) {

				case 'select':
					$post_list = $this->sort_posts($series_list[$serie], $orderby, $order);

					if ($auto_submit) $onchange_string = 'onChange="if (this.value!=\'\') { window.location=this.value}" ';
					else $onchange_string = '';

					foreach ($post_list as $post_id => $post_values) {

						$date_string = date_i18n($date_format, strtotime($post_values->post_date));
						if ($post_values->ID == $current_post_id) {
							$this_post = ' '.__('(This post)', $this->textdomain);
							$value     = '#';
							$class     = 'current';
						}
						else {
							$this_post = '';
							$class = '';
							$value     = get_permalink($post_values->ID);
						}
						$current_width = $width - strlen($this_post);
						if ($current_width>5 && strlen($post_values->post_title)>$current_width)
							$label = wp_html_excerpt( __($post_values->post_title), $current_width-3).'...';
						else 
							$label = __($post_values->post_title);

						$string .= '<option class="eg-series-posts-item '.$class.'" value="'.$value.'">'.
								htmlspecialchars($label).
								$this_post.
								($show_date?' -'.$date_string:'').
								'</option>';
					} // End of foreach
					// If list is not empty, finalize it
					if ($string  != '') {
						$string  = '<select class="eg-series-posts" id="series_list" name="series_list" '.$onchange_string.'>'.$string .'</select>';
					}
				break;

				case 'dl':
				case 'ul':
				case 'ol':
					if ($expand == 0)
						$post_list = $this->sort_posts($series_list[$serie], $orderby, $order);
					else {
						foreach ($series_list[$serie] as $data) {
							$id_list[] = $data->ID;
						}
						$post_list = get_posts('include='.implode(',',$id_list).'&order='.$order.'&orderby='.$orderby);
					}
					foreach ($post_list as $post_values) {

						$date_string = date_i18n($date_format, strtotime($post_values->post_date));
						if ($width>0 && strlen($post_values->post_title)>$width)
							$label = wp_html_excerpt( __($post_values->post_title), $width-3).'...';
						else
							$label = __($post_values->post_title);

						if ($post_values->ID == $current_post_id) {
							$post_title = $label;
							$this_post  = __('(This post)', $this->textdomain);
							$class      = 'current';
						}
						else {
							$post_title = '<a href="'.get_permalink($post_values->ID).'" title="'.htmlspecialchars($post_values->post_title).'">'.htmlspecialchars($label).'</a>';
							$this_post = '';
							$class     = '';
						}

						if ($list_type == 'dl') {
							$string .= '<dt class="eg-series-post-item '.$class.'">'.
								'<dfn>'.$post_title.'</dfn> '.
								($this_post!=''?'<span class="eg-series-post-this">'.$this_post.'</span>':'').
								($show_date||$expand?' <span class="eg-series-post-date date">'.$date_string.'</span>':'').
								'</dt>'.
								($expand?'<dd class="eg-series-post-excerpt">'.$this->get_excerpt($post_values).'</dd>':'');
						}
						else {
							$string .= '<li class="eg-series-posts-item '.$class.'">'.
								'<span class="eg-series-post-title">'.$post_title.'</span> '.
								($this_post!=''?'<span class="eg-series-post-this">'.$this_post.'</span>':'').
								($show_date||$expand?' <span class="eg-series-post-date date">'.$date_string.'</span>':'').
								($expand?'<span class="eg-series-post-excerpt">'.$this->get_excerpt($post_values).'</span>':'').'</li>';
						}
					} // End of foreach

					if ($string != '')
						$string = '<'.$list_type.' class="eg-series-posts">'.$string.'</'.$list_type.'>';

				break;
			} // End of switch list_type

			if ($string != '' && $title != '' && $titletag != '')
				$string = '<'.$titletag.'>'.htmlspecialchars(__($title, $this->textdomain)).'</'.$titletag.'>'.$string;

			return ($string);
		} /* End of get_posts */

		/**
		 * get_excerpt
		 *
		 * Extract and return excerpt from a post
		 *
		 * @package EG-Series
		 * @param object	$post				$post to extract excerpt
		 * @return string						excerpt of the specified post
		 */
		function get_excerpt($post) {

			if ( post_password_required($post) )
				$string = get_the_password_form();
			else {
				if (! empty($post->post_excerpt)) {
					$string = $post->post_excerpt;
				}
				else {
					if ( preg_match('/<!--more(.*?)?-->/', $post->post_content, $matches) )
						$string = current(explode($matches[0], $post->post_content, 2));
					else
						$string = wp_html_excerpt($post->post_content, 150);
				}
				$string = htmlspecialchars(strip_tags($string));
			}
			return ($string);
		} // End of get_excerpt

	} // End of class EG_Series_data
} // End of class_exists

?>