<?php

if (! class_exists('EG_Series')) {

	/**
	 * Class EG_Series
	 *
	 * Implement a shortcode to display the posts series
	 *
	 */
	Class EG_Series extends EG_Plugin_109 {

		var $series_data;

		/**
		 * init
		 *
		 * Initialize function: add metabox to the plugin
		 *
		 * @param 	none
		 * @return 	none
		 */
		function init() {

			// Call the parent init function
			parent::init();

			add_shortcode($this->options['shortcode_list_posts'],  array(&$this,'posts_shortcode') );
			add_shortcode($this->options['shortcode_list_series'], array(&$this,'series_shortcode') );

			if ($this->options['shortcode_auto']>0) {
				add_filter('the_content', array(&$this, 'posts_shortcode_auto'));
			}
		} // End of init

		/**
		 * series_shortcode
		 *
		 * Implement a shortcode to get the list of the series
		 *
		 * @param 	array		$attr		list of parameters sent to the shortcde
		 * @return 	string			html code
		 */
		function series_shortcode($attr) {
			global $EG_SERIES_SHORTCODE_SERIES_DEFAULTS;

			if (! isset($this->series_data))
				$this->series_data = & EG_Series_Data::get_instance($this->textdomain);

			extract( shortcode_atts( $EG_SERIES_SHORTCODE_SERIES_DEFAULTS, $attr ) );

			$string = $this->series_data->get_series($this->options['custom_field_name'],
												$listtype,			/* list_type		  */
												0, 					/* width 			  */
												$number, 			/* height			  */
												$title,				/* title			  */
												$titletag,			/* tag for title  	  */
												'series_list',		/* Select/option name */
												'',					/* default value      */
												1, 					/* auto_submit	  	  */
												$more,				/* more_series		  */
												0,					/* add no_serie 	  */
												$listposts,
												$show_date,
												$post_orderby,
												$post_order);

			return ('<div class="eg-series">'.$string.'</div>');
		}  /* End of series_shortcode */

		/**
		 * posts_shortcode
		 *
		 * Implement a shortcode to get the list of posts for a specified serie
		 *
		 * @param 	array		$attr		list of parameters sent to the shortcde
		 * @return 	string					html code
		 */
		function posts_shortcode($attr) {
			global $post;
			global $EG_SERIES_SHORTCODE_POSTS_DEFAULTS;

			if (! isset($this->series_data))
				$this->series_data = & EG_Series_Data::get_instance($this->textdomain);

			extract( shortcode_atts( $EG_SERIES_SHORTCODE_POSTS_DEFAULTS, $attr ));
			if ($id == 0) $id = $post->ID;

			$string = $this->series_data->get_posts($this->options['custom_field_name'],	/* Meta key */
												$name,									/* serie name */
												$id,									/* or post_id */
												$listtype,
												$width,
												0,
												$title,
												$titletag,
												TRUE,
												$orderby,
												$order,
												$show_date,
												'',
												$expand);
			return ('<div class="eg-series">'.$string.'</div>');

		} /* End of posts_shortcode */


		/**
		 * posts_shortcode_auto
		 *
		 * Implement a shortcode to get the list of posts for a specified serie
		 *
		 * @param 	strong	$content	post_content
		 * @return 	string			modified post content
		 */
		function posts_shortcode_auto($content = '') {
			global $post;

			if (! isset($this->series_data))
				$this->series_data = & EG_Series_Data::get_instance($this->textdomain);

			if ($this->options['shortcode_auto']>0) {

				$is_visible = FALSE;
				foreach ($this->options['shortcode_auto_where'] as $location) {
					switch ($location) {
						case 'home':
							$is_visible = $is_visible | is_home();
						break;

						case 'post':
							$is_visible = $is_visible | is_single();
						break;

						case 'page':
							$is_visible = $is_visible | is_page();
						break;

						case 'index':
							$is_visible = $is_visible | (is_category() || is_tag());
						break;
					}
				}
				if ( $is_visible ) {

					$content .= $this->series_data->get_posts(
									$this->options['custom_field_name'],		/* meta key 		*/
									'', 										/* Serie name 		*/
									$post->ID, 									/* id of current post */
									$this->options['shortcode_auto_listtype'],	/* type of list		*/
									0,											/* max width 		*/
									0,											/* height			*/
									$this->options['shortcode_auto_title'], 	/* title			*/
									$this->options['shortcode_auto_title_tag'], /* title tag		*/
									FALSE,										/* auto-submit		*/
									$this->options['shortcode_auto_orderby'],	/* orderby			*/
									$this->options['shortcode_auto_order'],		/* order			*/
									$this->options['shortcode_auto_show_date'],
									$this->options['date_format']);
				}
			}
			return ($content);
		}
	} /* End of Class */
} /* End of if class_exists */

/* ---------------------------------------------------------------------------------------------------------
     --- Plugin instance creation
     ------------------------------------------------------------------------------------------------------- */
$eg_series = new EG_Series(EG_SERIES_PLUGIN_NAME, EG_SERIES_VERSION, EG_SERIES_CORE_FILE, EG_SERIES_OPTIONS_ENTRY, $EG_SERIES_DEFAULT_OPTIONS);
$eg_series->set_textdomain(EG_SERIES_TEXTDOMAIN);
$eg_series->set_stylesheets('eg-series.css', FALSE);
$eg_series->set_wp_versions('2.5',	FALSE, FALSE, FALSE);
$eg_series->load();
?>