<?php

/* ---------------------------------------------------------------------------------
     --- Widgets declaration
     ------------------------------------------------------------------------------- */
if (! class_exists('EG_Series_Series_Widget')) {

	/**
	 * Class EG_Series_Widget
	 *
	 * Implement widget to display series
	 *
	 */
	Class EG_Series_Series_Widget extends EG_Widget_100 {

		var $series_data;

		/**
		 * Action
		 *
		 * Display the widget
		 *
		 * @param 	array	$args	Attributs of the widget
		 * @return 	string			HTML code
		 */
		function display( $args ) {

			// Is the widget visible (right category, or language)?
			if ( $this->is_visible() ) {

				if (!isset($this->series_data)) $this->series_data = & EG_Series_Data::get_instance($this->textdomain);

				// Yes => extract parameters
				$options = & $this->options;
				extract($args);

				$plugin_option = get_option(EG_SERIES_OPTIONS_ENTRY);
				if (isset($plugin_option)) $meta_key = $plugin_option['custom_field_name'];
				else $meta_key = '';

				// Display list of series
				$string = $this->series_data->get_series(
							$meta_key,
							$options['eg_series_series_format'],		/* list tag   		*/
							$options['eg_series_series_width'], 		/* width     		*/
							$options['eg_series_series_number'], 		/* height    		*/
							'',											/* title of list	*/
							'',											/* html tag for title */
							'series_list',								/* select id        */
							'',                                         /* Default value    */
							1,											/* auto_submit		*/
							$options['eg_series_series_more_series']);	/* more series 		*/			

				if ($string != '') {
					echo $before_widget;
					if ($options['eg_series_series_title']!= '') {
						echo $before_title . __($options['eg_series_series_title'], $this->textdomain) . $after_title;
					}
					echo $string. $after_widget;
				}
			}
		} /* End of function action */
	} /* End of class EG_Series_Series_Widget */


	Class EG_Series_Posts_Widget extends EG_Widget_100 {

		var $series_data;

		/**
		 * Action
		 *
		 * Display the widget
		 *
		 * @param 	array	$args	Attributs of the widget
		 * @return 	string		HTML code
		 */
		function display( $args ) {
			global $post;

			// Is the widget visible (right category, or language)?
			if ( $this->is_visible() ) {

				// Available only if on a post page
				if (is_single() || is_page()) {

					if (!isset($this->series_data)) $this->series_data = & EG_Series_Data::get_instance($this->textdomain);

					// Yes => extract parameters
					$options = & $this->options;
					extract($args);

					$plugin_option = get_option(EG_SERIES_OPTIONS_ENTRY);
					if (isset($plugin_option)) $meta_key = $plugin_option['custom_field_name'];
					else $meta_key = '';

					// Display list of series
					$string = $this->series_data->get_posts(
								$meta_key,
								'',
								$post->ID,
								$options['eg_series_posts_format'],		/* list tag   			*/
								$options['eg_series_posts_width'], 		/* width     			*/
								$options['eg_series_posts_number'], 	/* height    			*/
								'',										/* title of list		*/
								'',										/* html tag for title 	*/
								TRUE,									/* auto_submit			*/
								'date',									/* order by 			*/
								$options['eg_series_posts_order'],		/* order	 			*/
								$options['eg_series_posts_show_date'],	/* Show date 			*/
								'',										/* Date format			*/
								$options['eg_series_posts_expand']);	
								
					if ($string != '') {
						echo $before_widget;
						if ($options['eg_series_posts_title'] != '') {
							echo $before_title .__($options['eg_series_posts_title'], $this->textdomain) . $after_title;
						}
						echo $string. $after_widget;
					}
				}
			}
		} /* End of function action */
	} /* End of class EG_Series_Posts_Widget */

} /* End of class_exists */


$eg_widget_series_series = new EG_Series_Series_Widget('EG_Series_Series_Widget',	/* widget Id 			*/
			'EG-Series List',														/* Title 				*/
			'Display series or groups of posts',									/* widget description 	*/
			'widget_eg_series_series',												/* widget class			*/
			EG_SERIES_TEXTDOMAIN,													/* Text domain			*/
			EG_SERIES_CORE_FILE,
			3600,																	/* cache expiration		*/
			FALSE,																	/* display form to know if widget is visible or not */
			1,																		/* number of widgets instances */
			array(	'eg_series_series_title' => array(
						'type'    => 'text',
						'label'   => 'Title',
						'default' => 'Series'),
					'eg_series_series_format' => array(
						'type'    => 'select',
						'label'   => 'List format',
						'list'    => array('select' =>'Select',
										   'ul'     => 'Simple list',
										   'ol' 	=> 'Ordered list'),
						'default' => 'select'),
					'eg_series_series_number' => array(
						'type'    => 'numeric',
						'label'   => 'Number of series to display',
						'default' => 5),
					'eg_series_series_width' => array(
						'type'    => 'numeric',
						'label'   => 'Width',
						'default' => 30),
					'eg_series_series_more_series' => array(
						'type'    => 'numeric',
						'label'   => 'More series page/post id',
						'default' => 0)
			)
		);

$eg_widget_series_posts = new EG_Series_Posts_Widget('EG_Series_Posts_Widget',	/* widget Id 									*/
			'EG-Series Posts',												/* Title 											*/
			'Display posts of the same serie than the current post',		/* widget description 								*/
			'widget_eg_series_posts',										/* widget class										*/
			EG_SERIES_TEXTDOMAIN,											/* Text domain										*/
			EG_SERIES_CORE_FILE,
			3600,															/* cache expiration									*/
			FALSE,															/* display form to know if widget is visible or not */
			1,																/* number of widgets instances						*/
			array(	'eg_series_posts_title' => array(
						'type'    => 'text',
						'label'   => 'Title',
						'default' => 'Posts of the same serie'),
					'eg_series_posts_format' => array(
						'type'    => 'select',
						'label'   => 'List format',
						'list'    => array('select' => 'Select',
										   'ul'     => 'Simple list',
										   'ol' 	=> 'Ordered list'),
						'default' => 'select'),
					'eg_series_posts_number' => array(
						'type'    => 'numeric',
						'label'   => 'Number of posts to display',
						'default' => 5),
					'eg_series_posts_width' => array(
						'type'    => 'numeric',
						'label'   => 'Width',
						'default' => 30),
					'eg_series_posts_order' => array(
						'type'    => 'select',
						'label'   => 'Order by date',
						'list'    => array('ASC'  => 'Ascending',
										   'DESC' => 'Descending'),
						'default' => 'DESC'),
					'eg_series_posts_show_date' => array(
						'type'	  => 'checkbox',
						'label'   => 'Show date',
						'default' => 0),
					'eg_series_posts_expand' => array(
						'type'	  => 'checkbox',
						'label'   => 'Show posts details',
						'default' => 0)
			)
		);

$eg_widget_series_series->load();
$eg_widget_series_posts->load();

?>